package it.danieleverducci.subitobeers

import androidx.recyclerview.widget.RecyclerView
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ImageView
import android.widget.TextView
import com.squareup.picasso.Picasso

import it.danieleverducci.subitobeers.databinding.FragmentBeersListitemBinding
import it.danieleverducci.subitobeers.entities.Beer

class BeerRecyclerAdapter : RecyclerView.Adapter<BeerRecyclerAdapter.ViewHolder>() {

    var listener: Listener? = null
    private val items: ArrayList<Beer> = ArrayList()

    override fun onCreateViewHolder(parent: ViewGroup, viewType: Int): ViewHolder {
        // Create viewholder
        val vh = ViewHolder(
            FragmentBeersListitemBinding.inflate(
                LayoutInflater.from(parent.context),
                parent,
                false
            )
        )

        // Register click listener
        vh.root.setOnClickListener(object: View.OnClickListener{
            override fun onClick(v: View?) {
                if (v != null) {
                    listener?.OnItemClicked(v.getTag() as Beer)
                }
            }
        })

        return vh

    }

    override fun onBindViewHolder(holder: ViewHolder, position: Int) {
        val item = items[position]

        // Attach item to view to retrieve in case of click
        holder.root.setTag(item)

        // Fill layout with data
        holder.name.text = item.name
        holder.descr.text = item.tagline
        Picasso.get()
            .load(item.imageUrl)
            .placeholder(R.drawable.ic_launcher_foreground)
            .error(R.drawable.ic_launcher_foreground)
            .into(holder.pic)

        // If we are drawing the last element, notify
        if (position == items.size - 1)
            listener?.OnLastItemScrolled()
    }

    fun addItems(ni: List<Beer>) {
        items.addAll(ni);
        notifyDataSetChanged();
    }

    override fun getItemCount(): Int = items.size

    inner class ViewHolder(binding: FragmentBeersListitemBinding) : RecyclerView.ViewHolder(binding.root) {
        val root: View = binding.root
        val name: TextView = binding.beerItemName
        val descr: TextView = binding.beerItemDescr
        val pic: ImageView = binding.beerItemPic
    }

    interface Listener {
        fun OnItemClicked(item: Beer)
        fun OnLastItemScrolled()
    }

}